# Current info

```shell
➜  /tmp helm list
NAME                    NAMESPACE       REVISION        UPDATED                                         STATUS          CHART                           APP VERSION
cert-manager            cert-manager    1               2024-07-20 02:42:30.280467317 +0200 CEST        deployed        cert-manager-v1.15.1            v1.15.1    
cert-manager-ovh        cert-manager    1               2024-07-20 04:41:22.277311169 +0200 CEST        deployed        cert-manager-webhook-ovh-0.3.1  0.3.1      
cert-manager-porkbun    cert-manager    1               2024-07-20 05:17:54.537102326 +0200 CEST        deployed        porkbun-webhook-0.1.4           1.0   
```


# Supported versions

1.17 is supported until 1.29

https://cert-manager.io/docs/releases/#currently-supported-releases

# Upgrade

## Cert manager
### v1.16

```terraform
  # helm_release.cert-manager will be updated in-place
  ~ resource "helm_release" "cert-manager" {
        id                         = "cert-manager"
      ~ metadata                   = [
          - {
              - app_version    = "v1.15.1"
              - chart          = "cert-manager"
              - first_deployed = 1721436150
              - last_deployed  = 1721436150
              - name           = "cert-manager"
              - namespace      = "cert-manager"
              - notes          = <<-EOT
                    cert-manager v1.15.1 has been deployed successfully!
                    
                    In order to begin issuing certificates, you will need to set up a ClusterIssuer
                    or Issuer resource (for example, by creating a 'letsencrypt-staging' issuer).
                    
                    More information on the different types of issuers and how to configure them
                    can be found in our documentation:
                    
                    https://cert-manager.io/docs/configuration/
                    
                    For information on how to configure cert-manager to automatically provision
                    Certificates for Ingress resources, take a look at the `ingress-shim`
                    documentation:
                    
                    https://cert-manager.io/docs/usage/ingress/
                EOT
              - revision       = 1
              - values         = jsonencode(
                    {
                      - crds = {
                          - enabled = true
                          - keep    = true
                        }
                    }
                )
              - version        = "v1.15.1"
            },
        ] -> (known after apply)
        name                       = "cert-manager"
      ~ version                    = "v1.15.1" -> "v1.16.0"
        # (25 unchanged attributes hidden)

        # (2 unchanged blocks hidden)
    }

Plan: 0 to add, 1 to change, 0 to destroy.
```

```text
➜  Cert_Manager helm list
cert-manager        	cert-manager	2       	2025-02-22 21:41:27.702757947 +0100 CET 	deployed	cert-manager-v1.16.0          	v1.16.0 
```


### v1.17

```terraform
Terraform will perform the following actions:

  # helm_release.cert-manager will be updated in-place
  ~ resource "helm_release" "cert-manager" {
        id                         = "cert-manager"
      ~ metadata                   = [
          - {
              - app_version    = "v1.16.0"
              - chart          = "cert-manager"
              - first_deployed = 1721436150
              - last_deployed  = 1740256887
              - name           = "cert-manager"
              - namespace      = "cert-manager"
              - notes          = <<-EOT
                    cert-manager v1.16.0 has been deployed successfully!
                    
                    In order to begin issuing certificates, you will need to set up a ClusterIssuer
                    or Issuer resource (for example, by creating a 'letsencrypt-staging' issuer).
                    
                    More information on the different types of issuers and how to configure them
                    can be found in our documentation:
                    
                    https://cert-manager.io/docs/configuration/
                    
                    For information on how to configure cert-manager to automatically provision
                    Certificates for Ingress resources, take a look at the `ingress-shim`
                    documentation:
                    
                    https://cert-manager.io/docs/usage/ingress/
                EOT
              - revision       = 2
              - values         = jsonencode(
                    {
                      - crds = {
                          - enabled = true
                          - keep    = true
                        }
                    }
                )
              - version        = "v1.16.0"
            },
        ] -> (known after apply)
        name                       = "cert-manager"
      ~ version                    = "v1.16.0" -> "v1.17.0"
        # (25 unchanged attributes hidden)

        # (2 unchanged blocks hidden)
    }

Plan: 0 to add, 1 to change, 0 to destroy.
```

```text
➜  /tmp helm list
NAME                    NAMESPACE       REVISION        UPDATED                                         STATUS          CHART                           APP VERSION
cert-manager            cert-manager    3               2025-02-22 21:44:31.291530476 +0100 CET         deployed        cert-manager-v1.17.0            v1.17.0   
```


### v1.17.1

```terraform
Terraform will perform the following actions:

# helm_release.cert-manager will be updated in-place
~ resource "helm_release" "cert-manager" {
id                         = "cert-manager"
~ metadata                   = [
- {
- app_version    = "v1.17.0"
- chart          = "cert-manager"
- first_deployed = 1721436150
- last_deployed  = 1740257071
- name           = "cert-manager"
- namespace      = "cert-manager"
- notes          = <<-EOT
                    cert-manager v1.17.0 has been deployed successfully!
                    
                    In order to begin issuing certificates, you will need to set up a ClusterIssuer
                    or Issuer resource (for example, by creating a 'letsencrypt-staging' issuer).
                    
                    More information on the different types of issuers and how to configure them
                    can be found in our documentation:
                    
                    https://cert-manager.io/docs/configuration/
                    
                    For information on how to configure cert-manager to automatically provision
                    Certificates for Ingress resources, take a look at the `ingress-shim`
                    documentation:
                    
                    https://cert-manager.io/docs/usage/ingress/
                EOT
- revision       = 3
- values         = jsonencode(
{
- crds = {
- enabled = true
- keep    = true
}
}
)
- version        = "v1.17.0"
},
] -> (known after apply)
name                       = "cert-manager"
~ version                    = "v1.17.0" -> "v1.17.1"
# (25 unchanged attributes hidden)

# (2 unchanged blocks hidden)
}

Plan: 0 to add, 1 to change, 0 to destroy.
```

```text
➜  /tmp helm list
NAME                    NAMESPACE       REVISION        UPDATED                                         STATUS          CHART                           APP VERSION
cert-manager            cert-manager    4               2025-02-22 21:46:06.835196123 +0100 CET         deployed        cert-manager-v1.17.1            v1.17.1      
```

## Plugins

### Update local repos

```bash
➜  Cert_Manager git clone https://github.com/baarde/cert-manager-webhook-ovh.git ./tmp/cert-manager-webhook-ovh
Cloning into './tmp/cert-manager-webhook-ovh'...
remote: Enumerating objects: 435, done.
remote: Counting objects: 100% (137/137), done.
remote: Compressing objects: 100% (40/40), done.
remote: Total 435 (delta 113), reused 97 (delta 97), pack-reused 298 (from 2)
Receiving objects: 100% (435/435), 338.31 KiB | 2.94 MiB/s, done.
Resolving deltas: 100% (235/235), done.
➜  Cert_Manager git clone https://github.com/mdonoughe/porkbun-webhook ./tmp/cert-manager-webhook-porkbun      
Cloning into './tmp/cert-manager-webhook-porkbun'...
remote: Enumerating objects: 308, done.
remote: Counting objects: 100% (7/7), done.
remote: Compressing objects: 100% (6/6), done.
remote: Total 308 (delta 2), reused 1 (delta 1), pack-reused 301 (from 2)
Receiving objects: 100% (308/308), 260.79 KiB | 1.76 MiB/s, done.
Resolving deltas: 100% (129/129), done.
```

### Apply terraform

```terraform
Terraform will perform the following actions:

  # helm_release.cert-manager-porkbun will be updated in-place
  ~ resource "helm_release" "cert-manager-porkbun" {
        id                         = "cert-manager-porkbun"
        name                       = "cert-manager-porkbun"
      ~ version                    = "0.1.4" -> "0.1.5"
        # (25 unchanged attributes hidden)

        # (2 unchanged blocks hidden)
    }

Plan: 0 to add, 1 to change, 0 to destroy.

Do you want to perform these actions?
  Terraform will perform the actions described above.
  Only 'yes' will be accepted to approve.

  Enter a value: yes
```

```text
➜  Cert_Manager helm list
NAME                	NAMESPACE   	REVISION	UPDATED                                 	STATUS  	CHART                         	APP VERSION
cert-manager        	cert-manager	4       	2025-02-22 21:46:06.835196123 +0100 CET 	deployed	cert-manager-v1.17.1          	v1.17.1    
cert-manager-ovh    	cert-manager	1       	2024-07-20 04:41:22.277311169 +0200 CEST	deployed	cert-manager-webhook-ovh-0.3.1	0.3.1      
cert-manager-porkbun	cert-manager	2       	2025-02-22 21:50:59.096319059 +0100 CET 	deployed	porkbun-webhook-0.1.5         	1.0
```